@@ -32,15 +32,14 @@ from nxt import nxt_log, nxt_io, nxt_layer
 from nxt_editor.dialogs import (NxtFileDialog, NxtWarningDialog,
                                 UnsavedLayersDialogue, UnsavedChangesMessage)
 from nxt_editor import actions, LoggingSignaler
-from nxt.constants import API_VERSION, GRAPH_VERSION, USER_PLUGIN_DIR
+from nxt.constants import (API_VERSION, GRAPH_VERSION, USER_PLUGIN_DIR,
+                           NXT_DCC_ENV_VAR, is_standalone)
 from nxt.remote.client import NxtClient
 import nxt.remote.contexts
 from nxt_editor import qresources
 
 
-os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
 logger = logging.getLogger(nxt_editor.LOGGER_NAME)
-QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
 
 
 class MainWindow(QtWidgets.QMainWindow):
@@ -85,9 +84,10 @@ class MainWindow(QtWidgets.QMainWindow):
                 # logger.exception("Could not determine git branch.")
                 current_branch = ''
         os.chdir(old_cwd)
-        context = nxt.remote.contexts.get_current_context_exe_name()
-        if context.lower() == 'python':
+        if is_standalone():
             context = 'standalone'
+        else:
+            context = os.environ.get(NXT_DCC_ENV_VAR) or ''
         self.host_app = context
         self.setWindowTitle("nxt {} - Editor v{} | Graph v{} | API v{} "
                             "(Python {}) {}".format(self.host_app,
@@ -532,6 +532,7 @@ class MainWindow(QtWidgets.QMainWindow):
             self.model.effected_layers.remove(layer.real_path)
         except KeyError:  # Layer may not have been changed
             pass
+        self.model.layer_saved.emit(layer.real_path)
         self.set_waiting_cursor(False)
 
     def save_layer_as(self, layer=None, open_in_new_tab=True):
@@ -1003,6 +1004,12 @@ class MenuBar(QtWidgets.QMenuBar):
         self.file_menu.addSeparator()
         self.file_menu.addAction(self.layer_actions.ref_layer_above_action)
         self.file_menu.addAction(self.layer_actions.ref_layer_below_action)
+        self.file_menu.addSeparator()
+        self.builtins_menu = QtWidgets.QMenu('Reference Builtin Graph')
+        self.builtins_menu.aboutToShow.connect(partial(populate_builtins_menu,
+                                                       qmenu=self.builtins_menu,
+                                                       main_window=self.main_window))
+        self.file_menu.addMenu(self.builtins_menu)
         # Close app
         self.file_menu.addSeparator()
         self.file_menu.addAction(self.main_window.app_actions.close_tab_action)
@@ -1082,7 +1089,7 @@ class MenuBar(QtWidgets.QMenuBar):
                                                            'Context')
         remote_context_func = self.main_window.create_remote_context
         remote_context_action.triggered.connect(remote_context_func)
-        if nxt.remote.contexts.get_current_context_exe_name() == 'maya':
+        if not is_standalone():
             remote_context_action.setEnabled(False)
         self.remote_menu.addSeparator()
         self.remote_menu.addAction(self.exec_actions.enable_cmd_port_action)
@@ -1224,7 +1231,8 @@ class MenuBar(QtWidgets.QMenuBar):
         ui_dir = os.path.dirname(__file__)
         resources_file = os.path.join(ui_dir, 'qresources.py').replace(os.sep,
                                                                       '/')
-        resources_file_c = os.path.join(ui_dir, 'qresources.pyc').replace('/')
+        resources_file_c = os.path.join(ui_dir, 'qresources.pyc').replace(os.sep,
+                                                                          '/')
         success = False
         if os.path.isfile(resources_file):
             try:
@@ -1421,7 +1429,7 @@ class RecentFilesMenu(QtWidgets.QMenu):
             action = self.addAction('No recents found')
             action.setEnabled(False)
         for file_path in recents:
-            self.addAction(file_path)
+            self.addAction(str(file_path))
 
     def recent_selected(self, action):
         self.action_target(action.text())
@@ -1492,6 +1500,37 @@ class StartRPCThread(QtCore.QThread):
             self.main_window.model.processing.emit(False)
 
 
+def populate_builtins_menu(qmenu, main_window, layer=None):
+    """Populates a QMenu object with actions for referencing each builtin layer.
+    :param qmenu: QMenu object to be filled with actions
+    :param main_window: nxt MainWindow
+    :param layer: Optional layer to reference builtin layer under, if none is
+    supplied the target layer is used.
+    :return: QMenu
+    """
+    qmenu.clear()
+    stage_model = main_window.model
+    if not stage_model:
+        enable = False
+        idx = -1
+    else:
+        enable = True
+        layer = layer or stage_model.target_layer
+        idx = layer.layer_idx() + 1
+
+    for file_name in os.listdir(nxt_io.BUILTIN_GRAPHS_DIR):
+        if not file_name.endswith('.nxt'):
+            continue
+        new_action = qmenu.addAction(file_name)
+        path = '${var}/{file_name}'.format(var=nxt_io.BUILTIN_GRAPHS_ENV_VAR,
+                                           file_name=file_name)
+        if enable:
+            new_action.triggered.connect(partial(stage_model.reference_layer,
+                                                 path, idx))
+        new_action.setEnabled(enable)
+    return qmenu
+
+
 def nxt_execpthook(typ, value, tb):
     if 'nxt' not in tb.tb_frame.f_code.co_filename:
         return og_excepthook(typ, value, tb)
